@@ -411,10 +411,13 @@ our $aws_configure=sub {
 
       #cleanup pty for next run
       $pty->close();
-      system("sudo cp -R $homedir/.aws /home/$username")
+      my $sudo=($^O eq 'cygwin')?'':'sudo ';
+      system("${sudo}cp -R $homedir/.aws /home/$username")
          unless $homedir eq "/home/$username";
-      system("sudo chown -R $username:$username /home/$username/.aws");
-      system("sudo chmod 755 /home/$username/.aws");
+      my $group=$username;
+      $group='Administrators' if $username eq 'Administrator';
+      system("${sudo}chown -R $username:$group /home/$username/.aws");
+      system("${sudo}chmod 755 /home/$username/.aws");
 
    };
 
